package com.example.modular.warsaw;

import org.apache.wicket.protocol.http.WebApplication;
import org.apache.wicket.spring.injection.annot.SpringComponentInjector;
import org.wicketstuff.annotation.scan.AnnotatedMountScanner;

import com.example.modular.warsaw.pages.HomePage;

/**
 * Main Modular Warsaw web application class.
 * 
 * @author Krzysztof Smigielski
 */
public class WicketApplication extends WebApplication {

    private SpringComponentInjector springComponentInjector;

    public Class<HomePage> getHomePage() {
        return HomePage.class;
    }

    @Override
    protected void init() {
        super.init();
        if (springComponentInjector == null) {
            springComponentInjector = new SpringComponentInjector(this);
        }
        addComponentInstantiationListener(springComponentInjector);
        new AnnotatedMountScanner().scanPackage("com.example.modular.**.pages").mount(this);
    }

    /**
     * Component injector responsible for proper automounting of services to Wicket components. If
     * this property is not set, then
     * {@link SpringComponentInjector#SpringComponentInjector(WebApplication)} is called
     * automatically. This setter is useful for injecting mocks during tests.
     * 
     * @param pSpringComponentInjector Spring component injector.
     */
    public void setSpringComponentInjector(SpringComponentInjector pSpringComponentInjector) {
        springComponentInjector = pSpringComponentInjector;
    }

}
