package com.example.modular.warsaw.components;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;

import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.ajax.markup.html.AjaxFallbackLink;
import org.apache.wicket.markup.html.basic.Label;
import org.apache.wicket.model.PropertyModel;

/**
 * Labeled link that displays current date and time in a given time zone.
 * 
 * @author Krzysztof Smigielski
 */
public class TimeZoneLink extends AjaxFallbackLink<String> {

    private static final long serialVersionUID = 3164089732902220609L;

    private SimpleDateFormat date;
    private TimeZone timeZone;

    private String dateValue;
    private String dateLabel;

    /**
     * Default constructor.
     * 
     * @param pWicketId Wicket component id
     * @param pTimeZoneId id of the time zone
     */
    public TimeZoneLink(String pWicketId, String pTimeZoneId) {
        super(pWicketId);
        timeZone = TimeZone.getTimeZone(pTimeZoneId);
        date = new SimpleDateFormat("dd.MM.yyyy hh:mm:ss aaa (z)", Locale.ENGLISH);
        date.setTimeZone(timeZone);

        dateValue = date.format(new Date());
        dateLabel = "Time in " + timeZone.getID();

        add(new Label("label", new PropertyModel<String>(this, "dateLabel")));
        add(new Label("date", new PropertyModel<String>(this, "dateValue")));
    }

    @Override
    public void onClick(AjaxRequestTarget pTarget) {
        dateValue = date.format(new Date());
        if (pTarget != null) {
            // refresh whole link
            pTarget.addComponent(this);
        }
    }

    public String getDateValue() {
        dateValue = date.format(new Date());
        return dateValue;
    }

    public String getDateLabel() {
        return dateLabel;
    }

}
