package com.example.modular.warsaw.pages;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.wicket.Component;
import org.apache.wicket.markup.html.basic.Label;

import com.example.modular.BaseTestCase;
import com.example.modular.warsaw.components.TimeZoneLink;
import com.example.modular.warsaw.components.WarsawPanel;

/**
 * Warsaw page test.
 * 
 * @author Krzysztof Smigielski
 */
public class WarsawPageTest extends BaseTestCase {

    protected final Log log = LogFactory.getLog(getClass());

    @Override
    public void setUp() {
        super.setUp();
        tester.startPage(WarsawPage.class);
    }

    public void testRenderPage() {
        tester.assertRenderedPage(WarsawPage.class);
    }

    public void testComponents() {
        tester.assertComponent("panel", WarsawPanel.class);
        tester.assertLabel("panel:header", "Warsaw time zone page");
        tester.assertComponent("panel:tzLink", TimeZoneLink.class);
    }

    public void testLabelChanges() throws Exception {
        Component tzLink = tester.getComponentFromLastRenderedPage("panel:tzLink");
        assertNotNull(tzLink);
        assertTrue(tzLink.getClass().equals(TimeZoneLink.class));

        Label label = (Label) tester.getComponentFromLastRenderedPage("panel:tzLink:label");
        assertNotNull(label);
        Label date = (Label) tester.getComponentFromLastRenderedPage("panel:tzLink:date");
        assertNotNull(date);

        String labelPre = label.getDefaultModelObjectAsString();
        log.debug("labelPre : " + labelPre);
        String datePre = date.getDefaultModelObjectAsString();
        log.debug("datePre : " + datePre);

        log.info("wait 2 seconds");

        Thread.sleep(2000);

        tester.clickLink("panel:tzLink");
        assertTrue(tester.getLastRenderedPage().getClass().equals(WarsawPage.class));

        label = (Label) tester.getComponentFromLastRenderedPage("panel:tzLink:label");
        assertNotNull(label);
        date = (Label) tester.getComponentFromLastRenderedPage("panel:tzLink:date");
        assertNotNull(date);

        String labelPost = label.getDefaultModelObjectAsString();
        log.debug("labelPost : " + labelPost);
        String datePost = date.getDefaultModelObjectAsString();
        log.debug("datePost : " + datePost);

        assertTrue(labelPre.equals(labelPost));
        assertFalse(datePre.equals(datePost));
    }

}